@@ -111,6 +111,7 @@ class FileHDFio(object):
     """
 
     def __init__(self, file_name, h5_path="/", mode="a"):
+        file_name += ".h5" if not file_name.endswith(".h5") else ""
         if not os.path.isabs(file_name):
             raise ValueError("file_name must be given as absolute path name")
         self._file_name = None
@@ -1045,9 +1046,8 @@ class ProjectHDFio(FileHDFio):
     """
 
     def __init__(self, project, file_name, h5_path=None, mode=None):
+        file_name += ".h5" if not file_name.endswith(".h5") else ""
         self._file_name = file_name.replace("\\", "/")
-        if ".h5" not in file_name:
-            self._file_name += ".h5"
         if h5_path is None:
             h5_path = "/"
         self._project = project.copy()
