@@ -117,7 +117,7 @@ class Project(ProjectPath):
         self.sql_query = sql_query
         self._filter = ["groups", "nodes", "objects"]
         self._inspect_mode = False
-        self._store = None
+        self._data = None
         self._creator = Creator(project=self)
 
         if not s.database_is_disabled:
@@ -127,8 +127,6 @@ class Project(ProjectPath):
             self.db = FileTable(project=path)
         self.job_type = JobTypeChoice()
 
-        self._data = ProjectData(project=self, table_name="data")
-
     @property
     def parent_group(self):
         """
@@ -173,6 +171,12 @@ class Project(ProjectPath):
 
     @property
     def data(self):
+        if self._data is None:
+            self._data = ProjectData(project=self, table_name="data")
+            try:
+                self._data.read()
+            except KeyError:
+                pass
         return self._data
 
     def copy(self):
@@ -1395,28 +1399,6 @@ class Project(ProjectPath):
             {"groups": self.list_dirs(skip_hdf5=True), "nodes": self.list_nodes()}
         )
 
-    def __setitem__(self, key, value):
-        """
-        Store data in the ProjectStore container
-
-        Args:
-            key (str): key within the container
-            value (dict, list, float, int): data to store
-        """
-        if self.db is not None:
-            if self._store is None:
-                where_dict = {
-                    "job": "ProjectStore",
-                    "project": str(self.project_path),
-                    "subjob": "/ProjectStore",
-                }
-                store_job_id = self.db.get_items_dict(where_dict)["id"]
-                if store_job_id:
-                    self._store = self.load(store_job_id)
-                else:
-                    self._store = self.create_job("ProjectStore", "ProjectStore")
-            self._store[key] = value
-
     def _get_item_helper(self, item, convert_to_object=True):
         """
         Internal helper function to get item from project
